==> igniteui-react-core-18.1.0.tgz: package/esm5/lib/WebGridCellIdentifierDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridCellIdentifierDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridCellIdentifierDescription, _super);
    function WebGridCellIdentifierDescription() {
        var _this = _super.call(this) || this;
        _this.l = null;
        _this.g = 0;
        _this.h = 0;
        return _this;
    }
    WebGridCellIdentifierDescription.prototype.get_type = function () {
        return "WebGridCellIdentifier";
    };
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "rowIDRef", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("RowIDRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "columnID", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("ColumnID");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "rowIndex", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("RowIndex");
        },
        enumerable: false,
        configurable: true
    });
    WebGridCellIdentifierDescription.$t = markType(WebGridCellIdentifierDescription, 'WebGridCellIdentifierDescription', Description.$);
    WebGridCellIdentifierDescription.__marshalByValue = true;
    WebGridCellIdentifierDescription.__marshalByValueAlias = "GridCellIdentifier";
    return WebGridCellIdentifierDescription;
}(Description));
export { WebGridCellIdentifierDescription };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridCellIdentifierDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridCellIdentifierDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridCellIdentifierDescription, _super);
    function WebGridCellIdentifierDescription() {
        var _this = _super.call(this) || this;
        _this.l = null;
        _this.g = 0;
        _this.h = 0;
        return _this;
    }
    WebGridCellIdentifierDescription.prototype.get_type = function () {
        return "WebGridCellIdentifier";
    };
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "rowID", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("RowID");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "columnID", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("ColumnID");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridCellIdentifierDescription.prototype, "rowIndex", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("RowIndex");
        },
        enumerable: false,
        configurable: true
    });
    WebGridCellIdentifierDescription.$t = markType(WebGridCellIdentifierDescription, 'WebGridCellIdentifierDescription', Description.$);
    WebGridCellIdentifierDescription.__marshalByValue = true;
    WebGridCellIdentifierDescription.__marshalByValueAlias = "GridCellIdentifier";
    return WebGridCellIdentifierDescription;
}(Description));
export { WebGridCellIdentifierDescription };
